getStyleError method

  1. @override
Future<String?> getStyleError({
  1. required int mapId,
})

If the last attempt to set the style via MapConfiguration.style failed, returns the error information, otherwise returns null.

Implementation

@override
Future<String?> getStyleError({required int mapId}) async {
  return (await _hostApi(mapId).didLastStyleSucceed())
      ? null
      : _setStyleFailureMessage;
}