warmup method
Attempts to trigger any thread-blocking work the Google Maps SDK normally does when a map is shown for the first time.
Implementation
Future<void> warmup() async {
await _initializerApi.warmup();
}
Attempts to trigger any thread-blocking work the Google Maps SDK normally does when a map is shown for the first time.
Future<void> warmup() async {
await _initializerApi.warmup();
}